Exported from Notepad++

{ "type": "Feature", "properties": { "id": "PicAbi_KA09_P2T2", "species": "Picea abies", "source": "http://syssifoss.db", "measurements": [ { "source": "ALS", "date": "2019-07-05", "canopy_condition": "leaf-on", "height_m": 27.976, "crown_base_height_m": 8.25, "crown_projection_area_convex_hull_m2": 51.586, "crown_projection_area_concave_hull_m2": 40.903, "mean_crown_diameter_m": 8.267 }, { "crs": "epsg:25832", "position_xyz": [ 458628.651, 5432179.5, 161.65329 ] } ], "measurements_metadata": [ { "reference-url": "https://doi.org/10.5194/essd-2022-39" } ], "data": [ { "type": "pointcloud", "mode": "ALS", "date": "2019-07-05", "canopy_condition": "leaf-on", "sensor": "RIEGL VQ-780i", "point_count": 5861, "crs": "epsg:25832", "file": "https://3dweb.geog.uni-heidelberg.de/treedb/PicAbi_KA09_P2T2_2019-07-05_q3_ALS-on.laz", "metadata-url": "https://doi.org/10.5194/essd-2022-39", "quality": 3 } ] }, "geometry": { "type": "Point", "coordinates": [ 8.433906, 49.041104, 161.65329 ] } }